@@ -1,4 +1,5 @@
-/* GObject introspection: Dump introspection data
+/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*-
+ * GObject introspection: Dump introspection data
  *
  * Copyright (C) 2008 Colin Walters <walters@verbum.org>
  *
@@ -36,6 +37,9 @@
 
 #include <string.h>
 
+static void
+escaped_printf (GOutputStream *out, const char *fmt, ...) G_GNUC_PRINTF (2, 3);
+
 static void
 escaped_printf (GOutputStream *out, const char *fmt, ...)
 {
@@ -421,8 +425,10 @@ dump_error_quark (GQuark quark, const char *symbol, GOutputStream *out)
  *
  * Argument specified is a comma-separated pair of filenames; i.e. of
  * the form "input.txt,output.xml".  The input file should be a
- * UTF-8 Unix-line-ending text file, with each line containing the name
- * of a GType _get_type function.
+ * UTF-8 Unix-line-ending text file, with each line containing either
+ * "get-type:" followed by the name of a GType _get_type function, or
+ * "error-quark:" followed by the name of an error quark function.  No
+ * extra whitespace is allowed.
  *
  * The output file should already exist, but be empty.  This function will
  * overwrite its contents.
